Date class

Annotations
  • @JsonSerializable.new()

Constructors

Date(int year, int month, int day)
Date.fromJson(Map<String, dynamic> json)
factory

Properties

day → int
final
hashCode → int
The hash code for this object.
no setterinherited
month → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
year → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited