LocalLocation class

Annotations
  • @JsonSerializable.new()

Constructors

LocalLocation({double? x, double? y, double? z})
LocalLocation.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double?
East west location as angle.
final
y double?
North south location as angle.
final
z double?
Height in meters above sea level.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited