LocalOrientation class

Annotations
  • @JsonSerializable.new()

Constructors

LocalOrientation({double? roll, double? tilt, double? pan})
LocalOrientation.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pan → double?
Rotation around the X axis in degrees.
final
roll → double?
Rotation around the Z axis in degrees.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tilt → double?
Rotation around the Y axis in degrees.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited