LocationEntity class

Represents a geographic location with latitude, longitude, and optional elevation. This is used by ONVIF GetGeoLocation response.

Implemented types
Annotations
  • @JsonSerializable.new()

Constructors

LocationEntity({GeoLocation? geoLocation, GeoOrientation? geoOrientation, LocalLocation? localLocation, LocalOrientation? localOrientation, String? entity, String? token, bool? fixed, String? geoSource, bool? autoGeo})
LocationEntity.fromJson(Map<String, dynamic> json)
factory

Properties

autoGeo bool?
If set the geo location is obtained internally.
final
entity String?
Entity type the entry refers to, use a value from the tt:Entity enumeration.
final
fixed bool?
If this value is true the entity cannot be deleted.
final
geoLocation GeoLocation?
Location on earth.
final
geoOrientation GeoOrientation?
Orientation relative to earth.
final
geoSource String?
Optional reference to the XAddr of another devices DeviceManagement service.
final
hashCode int
The hash code for this object.
no setterinherited
localLocation LocalLocation?
Indoor location offset.
final
localOrientation LocalOrientation?
Indoor orientation offset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String?
Optional entity token.
final

Methods

buildXml(XmlBuilder builder, {String tag = 'Location', String? namespace}) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited