entity property
Entity type the entry refers to, use a value from the tt:Entity enumeration.
Implementation
@JsonKey(name: '@Entity', fromJson: OnvifUtil.nullableStringMappedFromXml)
final String? entity;
Entity type the entry refers to, use a value from the tt:Entity enumeration.
@JsonKey(name: '@Entity', fromJson: OnvifUtil.nullableStringMappedFromXml)
final String? entity;