fixed property
If this value is true the entity cannot be deleted.
Implementation
@JsonKey(name: '@Fixed', fromJson: OnvifUtil.nullableStringToBool)
final bool? fixed;
If this value is true the entity cannot be deleted.
@JsonKey(name: '@Fixed', fromJson: OnvifUtil.nullableStringToBool)
final bool? fixed;