NetworkProtocol class

Annotations
  • @JsonSerializable.new()

Constructors

NetworkProtocol({required String name, required bool enabled, required int port})
NetworkProtocol.fromJson(Map<String, dynamic> json)
factory

Properties

enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
port → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited