NetworkZeroConfiguration class

Zero-configuration settings (tt:NetworkZeroConfiguration).

Annotations
  • @JsonSerializable.new()

Constructors

NetworkZeroConfiguration({required String interfaceToken, required bool enabled, List<String> addresses = const []})
NetworkZeroConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

addresses List<String>
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
interfaceToken String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited