RelayOutputSettings class

Settings for a relay output (tt:RelayOutputSettings).

Implemented types
Annotations
  • @JsonSerializable.new()

Constructors

RelayOutputSettings({required RelayMode mode, required RelayIdleState idleState, String? delayTime})
RelayOutputSettings.fromJson(Map<String, dynamic> json)
factory

Properties

delayTime String?
Time after which the relay returns to its idle state (monostable mode); an xs:duration string such as PT1S.
final
hashCode int
The hash code for this object.
no setterinherited
idleState RelayIdleState
final
mode RelayMode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildXml(XmlBuilder builder, {String tag = 'Properties', String? namespace}) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited