SecurityCapabilities class

Security capabilities.

Annotations
  • @JsonSerializable.new()

Constructors

SecurityCapabilities({required bool tls1_0, required bool tls1_1, required bool tls1_2, required bool onboardKeyGeneration, required bool accessPolicyConfig, required bool defaultAccessPolicy, required bool dot1x, required bool remoteUserHandling, required bool x509Token, required bool samlToken, required bool kerberosToken, required bool relToken, Map<String, dynamic>? extension})
SecurityCapabilities.fromJson(Map<String, dynamic> json)
factory

Properties

accessPolicyConfig → bool
Indicates support for access policy configuration.
final
defaultAccessPolicy → bool
final
dot1x → bool
final
extension → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
kerberosToken → bool
Indicates support for WS-Security Kerberos token.
final
onboardKeyGeneration → bool
Indicates support for onboard key generation.
final
relToken → bool
Indicates whether or not WS-Security REL token is supported.
final
remoteUserHandling → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samlToken → bool
Indicates support for WS-Security SAML token.
final
tls1_0 → bool
Indicates support for TLS 1.0.
final
tls1_1 → bool
Indicates support for TLS 1.1.
final
tls1_2 → bool
Indicates support for TLS 1.2.
final
x509Token → bool
Indicates support for WS-Security X.509 token.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited