User class

Implemented types
Annotations
  • @JsonSerializable.new()

Constructors

User({required String username, String? password, required UserLevel userLevel, Map<String, dynamic>? extension})
User.fromJson(Map<String, dynamic> json)
factory
User.fromYamlMap(YamlMap yamlMap)
factory

Properties

extension → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
password → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userLevel → UserLevel
final
username → String
final

Methods

buildXml(XmlBuilder builder, {String tag = 'User', String? namespace}) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited