GetPresetsResponse class

Via this command the list of available Imaging Presets can be requested.

Annotations
  • @JsonSerializable.new()

Constructors

GetPresetsResponse({required List<ImagingPreset> presets})
GetPresetsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
presets → List<ImagingPreset>
List of Imaging Presets which are available for the requested VideoSource.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited