ImagingPreset class

List of Imaging Presets which are available for the requested VideoSource.

Annotations
  • @JsonSerializable.new()

Constructors

ImagingPreset({required String token, required String type, required String name})
ImagingPreset.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Human readable name of the Imaging Preset.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
Unique identifier of this Imaging Preset.
final
type → String
Indicates Imaging Preset Type. Use timg:ImagingPresetType. Used for multi-language support and display.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited