AudioSource class

List of existing Audio Sources

Annotations
  • @JsonSerializable.new()

Constructors

AudioSource({required String token, required int channels})
AudioSource.fromJson(Map<String, dynamic> json)
factory

Properties

channels → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
Unique identifier referencing the physical entity.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited