StreamingCapabilities class

Streaming capabilities.

Annotations
  • @JsonSerializable.new()

Constructors

StreamingCapabilities({required bool rtpMulticast, required bool rtp_tcp, required bool rtp_rtsp_tcp, required bool? nonAggregateControl, required bool? noRtspStreaming})
StreamingCapabilities.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nonAggregateControl → bool?
Indicates support for non aggregate RTSP control.
final
noRtspStreaming → bool?
Indicates the device does not support live media streaming via RTSP.
final
rtp_rtsp_tcp → bool
Indicates support for RTP/RTSP/TCP.
final
rtp_tcp → bool
Indicates support for RTP over TCP.
final
rtpMulticast → bool
Indicates support for RTP multicast.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited