Capabilities2 class

The capabilities for the media service is returned in the Capabilities element.

Annotations
  • @JsonSerializable.new()

Constructors

Capabilities2({required ProfileCapabilities profileCapabilities, required StreamingCapabilities streamingCapabilities, required bool snapshotUri, required bool rotation, required bool videoSourceMode, required bool osd, required bool? temporaryOSDText, required bool? exiCompression, bool? mask, bool? sourceMask})
Capabilities2.fromJson(Map<String, dynamic> json)
factory

Properties

exiCompression → bool?
Indicates the support for temporary osd text configuration.
final
hashCode → int
The hash code for this object.
no setterinherited
mask → bool?
Indicates if Masking is supported.
final
osd → bool
Indicates if OSD is supported.
final
profileCapabilities → ProfileCapabilities
Media profile capabilities.
final
rotation → bool
Indicates whether or not Rotation feature is supported.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotUri → bool
Indicates if GetSnapshotUri is supported.
final
sourceMask → bool?
Indicates that privacy masks are only supported at the video source level and not the video source configuration level. If this is true any addition, deletion or change of a privacy mask done for one video source configuration will automatically be applied by the device to a corresponding privacy mask for all other video source configuration associated with the same video source.
final
streamingCapabilities → StreamingCapabilities
Streaming capabilities.
final
temporaryOSDText → bool?
Indicates the support for temporary osd text configuration.
final
videoSourceMode → bool
Indicates the support for changing video source mode.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited