Time class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Time({dynamic xmlHour, dynamic xmlMinute, dynamic xmlSecond})
Time.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hour → int
no setter
minute → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
second → int
no setter
xmlHour → dynamic
final
xmlMinute → dynamic
final
xmlSecond → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited