VideoEncoderConfiguration class

If the video encoder configuration token is already known, the encoder configuration can be fetched through the GetVideoEncoderConfiguration command.

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

VideoEncoderConfiguration({required dynamic xmlName, required dynamic xmlUseCount, required dynamic xmlEncoding, required Resolution resolution, required dynamic xmlQuality, required RateControl rateControl, Mpeg4? mpeg4, H264? h264, required Multicast multiCast, required dynamic xmlSessionTimeout})
VideoEncoderConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

encoding → String
Used video codec, either Jpeg, H.264 or Mpeg4
no setter
h264 → H264?
Optional element to configure H.264 related parameters.
final
hashCode → int
The hash code for this object.
no setterinherited
mpeg4 → Mpeg4?
Optional element to configure Mpeg4 related parameters.
final
multiCast → Multicast
Defines the multicast settings that could be used for video streaming.
final
name → String
User readable name. Length up to 64 characters.
no setter
quality → double
Relative value for the video quantizers and the quality of the video. A high value within supported quality range means higher quality
no setter
rateControl → RateControl
Optional element to configure rate control related parameters.
final
resolution → Resolution
Configured video resolution
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionTimeout → String
The rtsp session timeout for the related video stream
no setter
useCount → int
Number of internal references currently using this configuration. This informational parameter is read-only. Deprecated for Media2 Service.
no setter
xmlEncoding → dynamic
final
xmlName → dynamic
final
xmlQuality → dynamic
final
xmlSessionTimeout → dynamic
final
xmlUseCount → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited