VideoSourceConfiguration class

Optional configuration of the Video input.

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

VideoSourceConfiguration(dynamic xmlName, dynamic xmlUseCount, dynamic sourceToken, Bounds bounds)
VideoSourceConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

bounds → Bounds
Rectangle specifying the Video capturing area. The capturing area shall not be larger than the whole Video source area.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
User readable name. Length up to 64 characters.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceToken → dynamic
Reference to the physical input.
final
useCount → int
Number of internal references currently using this configuration.
no setter
xmlName → dynamic
final
xmlUseCount → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited