stopMulticastStreaming method

Future<bool> stopMulticastStreaming(
  1. String profileToken
)

This command stop multicast streaming using a specified media profile of a device

profileToken - contains the token of the Profile that is used to define the multicast stream.

Implementation

Future<bool> stopMulticastStreaming(String profileToken) async =>
    _mediaSupportLevel == MediaSupportLevel.one
    ? media1.stopMulticastStreaming(profileToken)
    : media2.stopMulticastStreaming(profileToken);