PtzConfigurationOptions class

Annotations
  • @JsonSerializable.new()

Constructors

PtzConfigurationOptions({required List<int>? ptzRamps, required PtzSpaces spaces, required DurationRange ptzTimeout, required PtControlDirectionOptions? ptControlDirection, Map<String, dynamic>? extension})
PtzConfigurationOptions.fromJson(Map<String, dynamic> json)
factory

Properties

extension → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
ptControlDirection → PtControlDirectionOptions?
Supported options for PT Direction Control.
final
ptzRamps → List<int>?
The list of acceleration ramps supported by the device. The smallest acceleration value corresponds to the minimal index, the highest acceleration corresponds to the maximum index.
final
ptzTimeout → DurationRange
A timeout Range within which Timeouts are accepted by the PTZ Node.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spaces → PtzSpaces
A list of supported coordinate systems including their range limitations.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited