RecordingJobConfiguration class

Implemented types
Annotations
  • @JsonSerializable.new()

Constructors

RecordingJobConfiguration({String? scheduleToken, required String recordingToken, required RecordingJobConfigurationMode mode, required int priority, RecordingJobSource? source, Map<String, dynamic>? extension, RecordingEventFilter? eventFilter})
RecordingJobConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

eventFilter → RecordingEventFilter?
Optional filter defining on which event condition a recording job gets active.
final
extension → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
mode → RecordingJobConfigurationMode
Identifies the recording to which this job shall store the received data.
final
priority → int
List of recording jobs.
final
recordingToken → String
Identifies the recording to which this job shall store the received data.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduleToken → String?
This attribute adds an additional requirement for activating the recording job. If this optional field is provided the job shall only record if the schedule exists and is active.
final
source → RecordingJobSource?
Source of the recording.
final

Methods

buildXml(XmlBuilder builder, {String tag = 'JobConfiguration', String? namespace = Xmlns.trc}) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited