RecordingJobSource class

Source of the recording.

Implemented types
Annotations
  • @JsonSerializable.new()

Constructors

RecordingJobSource({SourceToken? sourceToken, bool? autoCreateReceiver, List<Track>? tracks, Map<String, dynamic>? extension})
RecordingJobSource.fromJson(Map<String, dynamic> json)
factory

Properties

autoCreateReceiver → bool?
If this field is TRUE, and if the SourceToken is omitted, the device shall create a receiver object (through the receiver service) and assign the ReceiverReference to the SourceToken field. When retrieving the RecordingJobConfiguration from the device, the AutoCreateReceiver field shall never be present.
final
extension → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceToken → SourceToken?
This field shall be a reference to the source of the data. The type of the source is determined by the attribute Type in the SourceToken structure. If Type is http://www.onvif.org/ver10/schema/Receiver, the token is a ReceiverReference. In this case the device shall receive the data over the network. If Type is http://www.onvif.org/ver10/schema/Profile, the token identifies a media profile, instructing the device to obtain data from a profile that exists on the local device.
final
tracks → List<Track>?
final

Methods

buildXml(XmlBuilder builder, {String tag = 'Source', String? namespace = Xmlns.trc}) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited