RecordingJobStateSource class

Identifies the data source of the recording job.

Annotations
  • @JsonSerializable.new()

Constructors

RecordingJobStateSource({required SourceToken sourceToken, required String state, required Tracks tracks})
RecordingJobStateSource.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceToken → SourceToken
Configuration of the recording.
final
state → String
Holds the aggregated state over all substructures of RecordingJobStateSource.
final
tracks → Tracks
Configuration of the recording.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited