RecordingSourceInformation class

Information about the source of the recording.

Implemented types
Annotations
  • @JsonSerializable.new()

Constructors

RecordingSourceInformation({required String sourceId, required String name, required String location, required String description, required String address})
RecordingSourceInformation.fromJson(Map<String, dynamic> json)
factory

Properties

address → String
Informative description of the physical location of the source, e.g. the coordinates on a map.
final
description → String
URI provided by the service supplying data to be recorded. A device shall support at least 128 characters.
final
hashCode → int
The hash code for this object.
no setterinherited
location → String
Informative description of the physical location of the source, e.g. the coordinates on a map.
final
name → String
Informative user readable name of the source, e.g. "Camera23". A device shall support at least 20 characters.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceId → String
Identifier for the source chosen by the client that creates the structure. This identifier is opaque to the device. Clients may use any type of URI for this field. A device shall support at least 128 characters.
final

Methods

buildXml(XmlBuilder builder, {String tag = 'Source', String? namespace = Xmlns.tt}) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited