MixedProfile class

A special case class that has the fields for both a media1 Profile and a media2 MediaProfile.

Annotations
  • @JsonSerializable.new()

Constructors

MixedProfile({required String token, required bool? fixed, required String name, ConfigurationSet? configurations, VideoSourceConfiguration? videoSourceConfiguration, AudioSourceConfiguration? audioSourceConfiguration, VideoEncoderConfiguration? videoEncoderConfiguration, AudioEncoderConfiguration? audioEncoderConfiguration, VideoAnalyticsConfiguration? videoAnalyticsConfiguration, PtzConfiguration? ptzConfiguration})
MixedProfile.fromJson(Map<String, dynamic> json)
factory
MixedProfile.fromMediaProfile(MediaProfile mediaProfile)
factory
MixedProfile.fromProfile(Profile profile)
factory

Properties

audioEncoderConfiguration → AudioEncoderConfiguration?
Optional configuration of the Audio encoder.
final
audioSourceConfiguration → AudioSourceConfiguration?
Optional configuration of the Audio input.
final
configurations → ConfigurationSet?
final
fixed → bool?
A value of true signals that the profile cannot be deleted. Default is false.
final
hashCode → int
The hash code for this object.
no setterinherited
isMedia2 → bool
no setter
name → String
User readable name of the profile.
final
ptzConfiguration → PtzConfiguration?
Optional configuration of the pan tilt zoom unit.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
Unique identifier of the profile.
final
videoAnalyticsConfiguration → VideoAnalyticsConfiguration?
Optional configuration of the video analytics module and rule engine.
final
videoEncoderConfiguration → VideoEncoderConfiguration?
Optional configuration of the Video encoder.
final
videoSourceConfiguration → VideoSourceConfiguration?
Optional configuration of the Video input.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited