WhiteBalance class

White balance settings.

Annotations
  • @JsonSerializable.new()

Constructors

WhiteBalance({required String mode, required double? crGain, required double? cbGain})
WhiteBalance.fromJson(Map<String, dynamic> json)
factory

Properties

cbGain → double?
Bgain (unit-less).
final
crGain → double?
Rgain (unit-less).
final
hashCode → int
The hash code for this object.
no setterinherited
mode → String
Auto white-balancing mode (auto/manual).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited