LoggingInterceptors class

Dio instance may have one or more interceptors by which you can intercept requests/responses/errors before they are handled by then or catchError.

Mixed-in types
  • UiLoggy

Constructors

LoggingInterceptors()

Properties

hashCode → int
The hash code for this object.
no setterinherited
loggy → Loggy<UiLoggy>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(DioException err, ErrorInterceptorHandler handler) → FutureOr
The callback will be executed on error.
onRequest(RequestOptions options, RequestInterceptorHandler handler) → FutureOr
The callback will be executed before the request is initiated.
onResponse(Response response, ResponseInterceptorHandler handler) → FutureOr
The callback will be executed on success.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited