GeoOrientation class
- Annotations
-
- @JsonSerializable.new()
Constructors
- GeoOrientation({double? roll, double? pitch, double? yaw})
-
GeoOrientation.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pitch → double?
-
Rotation around the Y axis in degrees.
final
- roll → double?
-
Rotation around the X axis in degrees.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- yaw → double?
-
Rotation around the Z axis in degrees.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited