WebrtcConfiguration class
WebRTC signaling configuration (tr2:WebRTCConfiguration).
Describes the signaling server a device uses for WebRTC streaming. The
easy_onvif_server reflects its own built-in /onvif/webrtc endpoint here.
- Implemented types
- Annotations
-
- @JsonSerializable.new()
Constructors
Properties
-
The Authorization Server used for obtaining access tokens.
final
- certPathValidationPolicyId → String?
-
Identifier of the policy used to validate the signaling server
certificate (optional).
final
- connected → bool?
-
Whether the device is connected to the signaling server (read-only).
final
- defaultProfile → String
-
The default media profile used for streaming.
final
- enabled → bool
-
Enables/disables the configuration.
final
- error → String?
-
Optional user readable error information (read-only).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signalingServer → String
-
The signaling server URI.
final
Methods
-
buildXml(
XmlBuilder builder, {String tag = 'WebRTCConfiguration', String? namespace = Xmlns.tr2}) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited