DeviceManagementRequest class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- builder → XmlBuilder
-
no setter
Static Methods
-
addIpAddressFilter(
{required IpAddressFilter ipAddressFilter}) → XmlDocumentFragment - XML for the addIpAddressFilter
-
capabilities(
String category) → XmlDocumentFragment - XML for the capabilities
-
createUsers(
List< User> users) → XmlDocumentFragment - XML for the createUsers
-
deleteGeoLocation(
List< LocationEntity> locations) → XmlDocumentFragment - XML for the deleteGeoLocation
-
deleteUsers(
List< String> userNames) → XmlDocumentFragment - XML for the deleteUsers
-
getDeviceInformation(
) → XmlDocumentFragment - XML for the getDeviceInformation
-
getDiscoveryMode(
) → XmlDocumentFragment - XML for the getDiscoveryMode
-
getDns(
) → XmlDocumentFragment - XML for the getDns
-
getDynamicDns(
) → XmlDocumentFragment - XML for the getDynamicDns
-
getEndpointReference(
) → XmlDocumentFragment - XML for the getEndpointReference
-
getGeoLocation(
) → XmlDocumentFragment - XML for the getGeoLocation
-
getHostname(
) → XmlDocumentFragment - XML for the getHostname
-
getIPAddressFilter(
) → XmlDocumentFragment - XML for the getIPAddressFilter
-
getNetworkDefaultGateway(
) → XmlDocumentFragment - XML for the getNetworkDefaultGateway
-
getNetworkProtocols(
) → XmlDocumentFragment - XML for the getNetworkProtocols
-
getNtp(
) → XmlDocumentFragment - XML for the getNtp
-
getRelayOutputs(
) → XmlDocumentFragment - XML for the getRelayOutputs
-
getServiceCapabilities(
) → XmlDocumentFragment - XML for the getServiceCapabilities
-
getServices(
[bool includeCapability = false]) → XmlDocumentFragment - XML for the getServices
-
getStorageConfiguration(
String referenceToken) → XmlDocumentFragment - XML for the getStorageConfiguration
-
getStorageConfigurations(
) → XmlDocumentFragment - XML for the getStorageConfigurations
-
getSystemDateAndTime(
) → XmlDocumentFragment - XML for the getSystemDateAndTime
-
getSystemLog(
String logType) → XmlDocumentFragment - XML for the getSystemLog
-
getSystemSupportInformation(
) → XmlDocumentFragment - XML for the getSystemSupportInformation
-
getSystemUris(
) → XmlDocumentFragment - XML for the getSystemUris
-
getUsers(
) → XmlDocumentFragment - XML for the getUsers
-
getZeroConfiguration(
) → XmlDocumentFragment - XML for the getZeroConfiguration
-
removeIpAddressFilter(
{required IpAddressFilter ipAddressFilter}) → XmlDocumentFragment - XML for the removeIpAddressFilter
-
setDns(
DnsInformation dnsInformation) → XmlDocumentFragment - XML for the setDns
-
setDynamicDns(
DynamicDnsInformation dynamicDnsInformation) → XmlDocumentFragment - XML for the setDynamicDns
-
setGeoLocation(
List< LocationEntity> locations) → XmlDocumentFragment - XML for the setGeoLocation
-
setHostname(
String name) → XmlDocumentFragment - XML for the setHostname
-
setHostnameFromDhcp(
bool fromDhcp) → XmlDocumentFragment - XML for the setHostnameFromDhcp
-
setIpAddressFilter(
{required IpAddressFilter ipAddressFilter}) → XmlDocumentFragment - XML for the setIpAddressFilter
-
setNetworkDefaultGateway(
NetworkGateway networkGateway) → XmlDocumentFragment - XML for the setNetworkDefaultGateway
-
setNetworkProtocols(
List< NetworkProtocol> networkProtocols) → XmlDocumentFragment - XML for the setNetworkProtocols
-
setNtp(
NtpInformation ntpInformation) → XmlDocumentFragment - XML for the setNtp
-
setRelayOutputSettings(
{required String relayOutputToken, required RelayOutputSettings properties}) → XmlDocumentFragment - XML for the setRelayOutputSettings
-
setRelayOutputState(
{required String relayOutputToken, required RelayLogicalState logicalState}) → XmlDocumentFragment - XML for the setRelayOutputState
-
setZeroConfiguration(
{required String interfaceToken, required bool enabled}) → XmlDocumentFragment - XML for the setZeroConfiguration
-
systemReboot(
) → XmlDocumentFragment - XML for the systemReboot